# Table of Contents

- [fact-sheet-owner-onboarding-dashboard](<./fact-sheet-owner-onboarding-dashboard.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Fact Sheet Owner Onboarding Dashboard](<./Fact-Sheet-Owner-Onboarding-Dashboard.md>)
  - [Introduction](<./Fact-Sheet-Owner-Onboarding-Dashboard/Introduction.md>)
  - [Activating the Dashboard](<./Fact-Sheet-Owner-Onboarding-Dashboard/Activating-the-Dashboard.md>)
  - [Dashboard Structure](<./Fact-Sheet-Owner-Onboarding-Dashboard/Dashboard-Structure.md>)
